@@ -8,9 +8,12 @@ from app import exclaimer
 
 if __name__ == '__main__':
     rqs = []
-    for i in range(0, 1):
-        promise = exclaimer.delay(str(i), paxd_timeout=2)
-        print promise.get()
+    for i in range(0, 100):
+        promise = exclaimer.delay(str(i), paxd_timeout=4)
+        rqs.append(promise)
+    
+    for pr in rqs:
+        print pr.get()
         # try:
         #     rqs.append(request.send())
         # except Exception, e:
